@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
    click_default_group
    ~~~~~~~~~~~~~~~~~~~
@@ -38,16 +37,17 @@
 """
 import click
 
-
 __all__ = ['DefaultGroup']
 __version__ = '1.1'
 
 
 class DefaultGroup(click.Group):
-    """Invokes a subcommand marked with `default=True` if any subcommand not
-    chosen.
-    :param default_if_no_args: resolves to the default command if no arguments
-                               passed.
+    """Invokes a subcommand marked with `default=True` if any subcommand not chosen.
+
+    Parameters
+    ----------
+    default_if_no_args :
+        resolves to the default command if no arguments passed.
     """
 
     def __init__(self, *args, **kwargs):
@@ -74,6 +74,7 @@ class DefaultGroup(click.Group):
                     raise RuntimeError('Default command already defined')
                 self.default_cmd_name = cmd.name
             return cmd
+
         return _decorator
 
     def parse_args(self, ctx, args):
