@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, print_function, unicode_literals
-
-
 class VCSPullException(Exception):
 
     """Standard exception raised by libvcs."""
