@@ -1,14 +1,15 @@
-# -*- coding: utf-8 -*-
-"""Log utilities for vcspull.
+"""Log utilities for formatting CLI output.
 
 vcspull.log
 ~~~~~~~~~~~
 
+This module containers special formatters for processing the additional context
+information from :class:`libvcs.base.RepoLoggingAdapter`.
+
+Colorized formatters for generic logging inside the application is also
+provded.
+
 """
-
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals, with_statement)
-
 import logging
 import time
 
@@ -19,33 +20,45 @@ LEVEL_COLORS = {
     'INFO': Fore.GREEN,  # Green
     'WARNING': Fore.YELLOW,
     'ERROR': Fore.RED,
-    'CRITICAL': Fore.RED
+    'CRITICAL': Fore.RED,
 }
 
 
 def default_log_template(self, record):
     """Return the prefix for the log message. Template for Formatter.
 
-    :param: record: :py:class:`logging.LogRecord` object. this is passed in
-    from inside the :py:meth:`logging.Formatter.format` record.
-
+    Parameters
+    ----------
+    record : :py:class:`logging.LogRecord`
+        This is passed in from inside the :py:meth:`logging.Formatter.format` record.
     """
-
     reset = [Style.RESET_ALL]
     levelname = [
-        LEVEL_COLORS.get(record.levelname), Style.BRIGHT,
+        LEVEL_COLORS.get(record.levelname),
+        Style.BRIGHT,
         '(%(levelname)s)',
-        Style.RESET_ALL, ' '
+        Style.RESET_ALL,
+        ' ',
     ]
     asctime = [
-        '[', Fore.BLACK, Style.DIM, Style.BRIGHT,
+        '[',
+        Fore.BLACK,
+        Style.DIM,
+        Style.BRIGHT,
         '%(asctime)s',
-        Fore.RESET, Style.RESET_ALL, ']'
+        Fore.RESET,
+        Style.RESET_ALL,
+        ']',
     ]
     name = [
-        ' ', Fore.WHITE, Style.DIM, Style.BRIGHT,
+        ' ',
+        Fore.WHITE,
+        Style.DIM,
+        Style.BRIGHT,
         '%(name)s',
-        Fore.RESET, Style.RESET_ALL, ' '
+        Fore.RESET,
+        Style.RESET_ALL,
+        ' ',
     ]
 
     tpl = "".join(reset + levelname + asctime + name + reset)
@@ -67,9 +80,7 @@ class LogFormatter(logging.Formatter):
             record.message = "Bad message (%r): %r" % (e, record.__dict__)
 
         date_format = '%H:%m:%S'
-        record.asctime = time.strftime(
-            date_format, self.converter(record.created)
-        )
+        record.asctime = time.strftime(date_format, self.converter(record.created))
 
         prefix = self.template(record) % record.__dict__
 
@@ -78,40 +89,54 @@ class LogFormatter(logging.Formatter):
 
 
 def debug_log_template(self, record):
-    """ Return the prefix for the log message. Template for Formatter.
-
-    :param: record: :class:`logging.LogRecord` object. this is passed in
-    from inside the :py:meth:`logging.Formatter.format` record.
+    """Return the prefix for the log message. Template for Formatter.
 
+    Parameters
+    ----------
+    record : :class:`logging.LogRecord`
+        This is passed in from inside the :py:meth:`logging.Formatter.format` record.
     """
 
     reset = [Style.RESET_ALL]
     levelname = [
-        LEVEL_COLORS.get(record.levelname), Style.BRIGHT,
+        LEVEL_COLORS.get(record.levelname),
+        Style.BRIGHT,
         '(%(levelname)1.1s)',
-        Style.RESET_ALL, ' '
+        Style.RESET_ALL,
+        ' ',
     ]
     asctime = [
-        '[', Fore.BLACK, Style.DIM, Style.BRIGHT,
-        '%(asctime)s', Fore.RESET, Style.RESET_ALL, ']'
+        '[',
+        Fore.BLACK,
+        Style.DIM,
+        Style.BRIGHT,
+        '%(asctime)s',
+        Fore.RESET,
+        Style.RESET_ALL,
+        ']',
     ]
     name = [
-        ' ', Fore.WHITE, Style.DIM, Style.BRIGHT,
+        ' ',
+        Fore.WHITE,
+        Style.DIM,
+        Style.BRIGHT,
         '%(name)s',
-        Fore.RESET, Style.RESET_ALL, ' '
-    ]
-    module_funcName = [
-        Fore.GREEN, Style.BRIGHT,
-        '%(module)s.%(funcName)s()'
+        Fore.RESET,
+        Style.RESET_ALL,
+        ' ',
     ]
+    module_funcName = [Fore.GREEN, Style.BRIGHT, '%(module)s.%(funcName)s()']
     lineno = [
-        Fore.BLACK, Style.DIM, Style.BRIGHT, ':', Style.RESET_ALL,
-        Fore.CYAN, '%(lineno)d'
+        Fore.BLACK,
+        Style.DIM,
+        Style.BRIGHT,
+        ':',
+        Style.RESET_ALL,
+        Fore.CYAN,
+        '%(lineno)d',
     ]
 
-    tpl = ''.join(
-        reset + levelname + asctime + name + module_funcName + lineno + reset
-    )
+    tpl = ''.join(reset + levelname + asctime + name + module_funcName + lineno + reset)
 
     return tpl
 
@@ -124,20 +149,16 @@ class DebugLogFormatter(LogFormatter):
 
 
 class RepoLogFormatter(LogFormatter):
-
     def template(self, record):
-        record.message = ''.join([
-            Fore.MAGENTA, Style.BRIGHT,
-            record.message,
-            Fore.RESET,
-            Style.RESET_ALL
-        ])
+        record.message = ''.join(
+            [Fore.MAGENTA, Style.BRIGHT, record.message, Fore.RESET, Style.RESET_ALL]
+        )
         return '%s|%s| %s(%s) %s' % (
             Fore.GREEN + Style.DIM,
             record.repo_name,
             Fore.YELLOW,
             record.repo_vcs,
-            Fore.RESET
+            Fore.RESET,
         )
 
 
