@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """Utility functions for vcspull.
 
 vcspull.util
 ~~~~~~~~~~~~
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
-
 import os
 
 from libvcs._compat import PY2
@@ -22,14 +19,19 @@ CONFIG_DIR = os.path.expanduser('~/.vcspull/')  # remove dupes of this
 def update_dict(d, u):
     """Return updated dict.
 
-    http://stackoverflow.com/a/3233356
+    Parameters
+    ----------
+    d : dict
+    u : dict
 
-    :param d: dict
-    :type d: dict
-    :param u: updated dict.
-    :type u: dict
-    :rtype: dict
+    Returns
+    -------
+    dict :
+        Updated dictionary
 
+    Notes
+    -----
+    Thanks: http://stackoverflow.com/a/3233356
     """
     for k, v in u.items():
         if isinstance(v, Mapping):
